/*
 * Copyright 2021 - All rights reserved.
 * Rodrigo Tapia-McClung
 *
 * January 2021
 */

/* globals map, userFiles, userDates, indicators, indicatorVars, indicatorsNames */
/* exported makeIndicatorGraph, getData, updateData, getDataInSelection */

let mainTextColor = getComputedStyle(document.body).getPropertyValue('--main-text-color');
let minDate, maxDate, xLine, yLine;

const sortByDateAscending = (a, b) => {
    // Dates will be cast to numbers automagically:
    return a.date - b.date;
}

//TODO: scale data to appropriate units? m2-> ha? m -> km?
const getData = async() => {
    let queryColumns = ["sum(areacpo) as area", "sum(perimcpo) as perimeter", "avg(dlccpo) as costa", "avg(dimfrcpo) as df"],
        timeParse = d3.timeParse("cuerpos_%B_%Y"),
        data = {};

    indicators.map(indicator => {
        data[indicator] = [];
        data[indicator].push({ name: `${indicator}0`, values: [] });
    });

    const baseUrl = new URL(`/data`, window.location.href).href;
    const userFilePromises = userFiles.map(async monthYear => {
        let queryDB = `${baseUrl}/query/${monthYear}?columns=${queryColumns.join(",")}`;
        const dbData = await d3.json(queryDB);
        return { date: timeParse(monthYear), value: dbData[0] };
    });

    const chartData = await Promise.all(userFilePromises);
    chartData.map(monthData => {
        indicators.map(indicator => {
            data[indicator][0].values.push({
                "date": monthData.date,
                "value": +monthData.value[indicator]
            });
            // order data[i].values.date
            data[indicator].forEach(d => d.values.sort(sortByDateAscending));
        });
    });
    return data;
}

const getDataInSelection = async() => {
    let geojson = drawnItems.toGeoJSON(),
        queryColumns = ["sum(area) as area", "sum(perimeter) as perimeter", "avg(costa) as costa", "avg(df) as df"],
        timeParse = d3.timeParse("%B_%Y"),
        data = {};

    indicators.map(indicator => {
        data[indicator] = [];
    });

    const baseUrl = new URL(`/data`, window.location.href).href;

    // Convert drawn items to GeoJSON and check what's inside each one of them
    const drawnItemPromises = drawnItems.toGeoJSON().features.map(async(item, i) => {
        // set SRID fro drawn features
        geojson.features[i].geometry.crs = { "type": "name", "properties": { "name": "EPSG:4326" } };
        indicators.map(async indicator => {
            data[indicator].push({ name: indicator + (i + 1), values: [] });
        });
        // End up with data = {area: [{name: "area1", values: []}], perimeter: [{name: "perimeter1", values: []}]...}

        let filter = `ST_Intersects(geom, (SELECT ST_Multi(ST_GeomFromGeoJSON('${JSON.stringify(geojson.features[i].geometry)}') ) ) )`
        const userFilePromises = userFiles.map(async monthYear => {
            let queryData = `${baseUrl}/query/${monthYear}?columns=${queryColumns.join(",")}&filter=${filter}&group=1%3D1`;
            const selectionQuery = await d3.json(queryData);
            return { date: timeParse(monthYear), value: selectionQuery[0] };
        });
        const selectionData = await Promise.all(userFilePromises);
        selectionData.map(itemData => {
            indicators.map(indicator => {
                let itemDataValue = itemData.value != undefined ? itemData.value[indicator] : 0;
                data[indicator][i].values.push({ date: itemData.date, value: itemDataValue });
            });
        });
    });
    const drawnItemsData = await Promise.all(drawnItemPromises);
    return data;
}

const summarizeData = (allData, indicator) => {
    let dataFull = allData;
    let data = dataFull[indicator];
    let data2 = [];
    data.map(a => data2.push(a.values)); // flatten array of data[i].values
    data2 = [].concat.apply([], data2);
    // insert sum of each date to first element of data array with name "column0"
    data.unshift({
        "name": `${indicator}0`,
        "values": d3.nest()
            .key(d => d.date)
            // return d3.sum or d3.average depending on indicator
            .rollup(v => { return indicator == "costa" || indicator == "df" ? d3.mean(v, v => v.value) : d3.sum(v, v => v.value) })
            .entries(data2)
            // map "key" and "value" from d3.nest().rollup() to date and value
            .map(group => {
                return {
                    date: new Date(group.key),
                    value: group.value
                }
            })
    });
    // order data[i].values.date
    data.forEach(d => d.values.sort(sortByDateAscending));
    return data;
}

const makeIndicatorGraph = () => {

    let data = [],
        width = 450,
        height = 400,
        padding = 30,
        margin = { top: 5, right: 10, bottom: 100, left: 35 },
        id, // variable in data to use as identifier
        lineVariables = null, // list of variables to display as lines
        displayName, // variable in data to use as x axis labels
        transitionTime = 500,
        //lineColor = "#17678E",
        //pointColor = "#17678E",
        defaultLineColor = "CadetBlue",
        defaultPointColor = "CadetBlue",
        lineColors = d3.scaleOrdinal(d3.schemeCategory10),
        pointColors = d3.scaleOrdinal(d3.schemeCategory10),
        lineAxisLabel = "",
        xAxisFormat = d3.timeFormat("%b '%y"), // mm 'yy
        yAxisFormat = d3.format(".2s"), // SI format with 2 significant numbers
        //rightAxisFormat = ".0%", // rounded percentage
        legend = false,
        title = "",
        tooltipUnits = "",
        tooltipFormat = "",
        //legend = {title: "title", translateX: 100, translateY: 0, items:["item1","item2"]}
        legendContainer = "legendZone",
        updateData;

    const chart = selection => {
        // get data ranges using values from displayName
        minDate = d3.min(data[0].values, d => {
            return d[displayName];
        });
        minDate = d3.timeDay.offset(minDate, -15) // get previous month to get correct x-axis alignment
        maxDate = d3.max(data[0], d => {
            return d[displayName];
        });
        maxDate = d3.timeDay.offset(maxDate, 15) // get next month to get correct x-axis alignment

        selection.each(() => {

            // add graph svg to selected container on webpage
            let areaSVG = selection
                .append("svg")
                // don't set height/width but use viewBox so charts get resized
                // if they are within a container that can be resized (also scales text)
                .attr("viewBox", `0 0 ${width} ${height}`)
                //.attr("preserveAspectRatio", "xMinYMin meet"),
                .attr("preserveAspectRatio", "xMidYMid meet"),

                g = areaSVG.append("g")
                .attr("class", "lineChart")
                .attr("transform", `translate(${margin.left}, ${margin.top})`);

            // add x axis
            g.append("g")
                .attr("class", "x axis")
                .attr("transform", `translate(30, ${height - margin.left})`);
            // add x axis for ticks
            g.append("g")
                .attr("class", "x axis-ticks")
                .attr("transform", `translate(30, ${height - margin.left})`);
            // add x axis for month labels
            g.append("g")
                .attr("class", "x axis-month-labels")
                .attr("transform", `translate(30, ${height - margin.left})`);
            // add x axis for year labels
            g.append("g")
                .attr("class", "x axis-year-labels")
                .attr("transform", `translate(30, ${height - margin.left + 12})`);
            //add left y axis
            g.append("g")
                .attr("class", "y axis")
                .attr("transform", "translate(30,0)");

            //label y axes
            areaSVG.append("text")
                .attr("class", "label")
                .attr("text-anchor", "middle") // this makes it easy to centre the text as the transform is applied to the anchor
                .attr("transform", `translate(${padding / 3}, ${height / 2}) rotate(-90)`) // text is drawn off the screen top left, move down and out and rotate
                .attr("fill", "#b2b2b2");
            //.text("Superficie inundada");

            // append line container
            g.append("g")
                .attr("class", "lines")
                .attr("transform", "translate(30, 0)");
            // append circle container
            g.append("g")
                .attr("class", "circles")
                .attr("transform", "translate(30, 0)");

            // add chart title container
            areaSVG.append("text")
                .attr("class", "title label")
                .attr("text-anchor", "middle") // this makes it easy to centre the text as the transform is applied to the anchor
                .attr("transform", `translate(${width / 2}, ${margin.top * 4})`); // text is drawn off the screen top left, move down and out and rotate

            // add the tooltip area to the webpage
            let tooltip;
            if (d3.select("div.tooltip").empty()) { // check if no tooltip div exists and add if necessary
                tooltip = d3.select("body").append("div")
                    .attr("class", "tooltip")
                    .style("opacity", 0);
            }

            // define axes with ranges
            xLine = d3.scaleTime().range([0, width - margin.left - margin.right - 30]).clamp(true);
            yLine = d3.scaleLinear().range([height - margin.left - margin.right, 0 + 35])

            // scale data range
            xLine.domain([minDate, maxDate]).nice();
            //yLine.domain(d3.extent(data, function(d) { return d[lineVariables[0]]; })).nice();
            //yLine.domain([0, d3.max(data, function(d) { return d[lineVariables[0]]; })]).nice();

            // Calculate min and max values of data to define chart y-axis domain
            //let minDomain = d3.min(data.map(d => d.values).flat().map(d => d.value));

            //console.log("data: ", data.map(d => d.values));

            let maxDomain = d3.max(data.map(d => d.values).flat().map(d => d.value));
            yLine.domain([0, maxDomain]).nice();
            //yLine.domain([0, d3.max(data[0].values, d => d.value)]).nice();

            // add axes
            let xaxis = g.select(".x.axis");
            xaxis.call(
                    d3.axisBottom(xLine)
                    //    .ticks(d3.timeMonth.every(1))
                    //    .tickFormat(d3.timeFormat("%b '%y"))
                )
                .selectAll("text")
                //.attr("y", 0)
                //.attr("x", 9)
                .attr("y", 15)
                .attr("x", 0)
                .attr("dy", ".35em")
                .attr("font-size", "12px")
                //.attr("transform", "rotate(90)")
                //.style("text-anchor", "start");
                .style("text-anchor", "middle")
                .style("fill", "#b2b2b2");

            // format x-axis lines for minor and major ticks
            //TODO: check this line to separate years starting in Jan. Maybe it is not needed
            xaxis.selectAll("g.tick line")
                .attr("y2", d => { // d is the tick value
                    if (d3.timeFormat("%m")(d) == "01") //if it is Jan
                        return -height - 6;
                    else
                        return 6;
                })
                .attr("transform", d => { // d is the tick value
                    if (d3.timeFormat("%m")(d) == "01") //if it is Jan
                        return "translate(0,6)";
                })
                .attr("class", d => { // d is the tick value
                    if (d3.timeFormat("%m")(d) == "01") //if it is Jan
                        return "yearTick";
                });

            let yaxis = g.select(".y.axis");
            yaxis.transition()
                .duration(500)
                .call(d3.axisLeft(yLine)
                    /*.tickFormat(d3.format(".2s"))*/
                );

            // color axis labels
            g.selectAll(".y.axis g.tick text")
                .style("fill", "#b2b2b2"); // function (d,i) {return (i%2)?"red":"blue";})

            let title = selection.select(".title.label");
            title.text(chart.title())
                .style("fill", "#b2b2b2");

            selection.select(".title.label")
                .append("tspan")
                .attr("class", "far")
                .html(" \uf059")
                //.style("color", "#b2b2b2")
                .style("cursor", "pointer")
                .on("click", () => { // when clicking ? display modal with information about indicator
                    $("#explainIndicatorModal").on("show.bs.modal", () => {
                        let indicatorName = indicatorsNames[indicators.indexOf(id)]
                        $("#explainIndicatorModal").find("#explainIndicatorModalTitle").text(indicatorName);
                        $("#explainIndicatorModal").find(".modal-body").html(indicatorVars[id].explanation);
                    });
                    $("#explainIndicatorModal").modal();
                });

            // update chart
            updateData = () => {
                let time = map.timeDimension.getCurrentTime();

                // update data ranges using values from displayName and lineVariables
                minDate = d3.min(data[0].values, d => {
                    return d[displayName];
                });

                minDate = d3.timeDay.offset(minDate, -15) // get previous month to get correct x-axis alignment
                maxDate = d3.max(data[0].values, d => {
                    return d[displayName];
                });
                maxDate = d3.timeDay.offset(maxDate, 15) // get next month to get correct x-axis alignment

                // update axes' domain
                xLine.domain([minDate, maxDate])
                    //.nice()
                    //.nice(d3.timeMonth)
                    .range([0, width - margin.left - margin.right - 30])
                    .clamp(true);
                //yLine.domain(d3.extent(data, function(d) { return d[lineVariables[0]]; }))
                //yLine.domain([0, d3.max(data, function(d) { return d[lineVariables[0]]; })]).nice()

                // Calculate min and max values of data to define chart y-axis domain
                //let minDomain = d3.min(data.map(d => d.values).flat().map(d => d.value));
                let maxDomain = d3.max(data.map(d => d.values).flat().map(d => d.value));
                yLine.domain([0, maxDomain])
                    //yLine.domain([0, d3.max(data[0].values, d => d.value)]).nice()
                    .range([height - margin.left - margin.right, 0 + 35])
                    .nice();

                // filter data to only use the ones needed for current time
                let filteredData = [];
                data.forEach((d, i) => {
                    filteredData.push({
                        name: d.name,
                        values: []
                    });
                    d.values.filter(v => {
                        if (v.date <= new Date(time)) {
                            filteredData[i].values.push(v);
                        }
                    });
                });

                // update axes
                let g = selection.select(".lineChart");

                // update axis line with no ticks
                let xaxis = g.select(".x.axis");
                xaxis.transition()
                    .duration(500)
                    .call(
                        d3.axisBottom(xLine)
                        .ticks(0)
                        .tickSize(0)
                    );

                // update axis ticks - one for each month
                let xaxisTicks = g.select(".x.axis-ticks");
                let monthsInGraph = [];
                userDates.forEach(d => {
                    monthsInGraph.push(new Date(d));
                });

                xaxisTicks.transition()
                    .duration(500)
                    .call(
                        d3.axisBottom(xLine)
                        .tickValues(monthsInGraph)
                        .tickFormat("")
                    );

                // update axis month labels depending on how many months there are
                let xaxisLabels = g.select(".x.axis-month-labels");
                // FIXME: check how this displays ticks when there are many months/years
                // this fix gives up to 10 ticks
                // maybe need to set up more conditions
                let numberOfTicks = monthsInGraph.length < 6 ? d3.timeMonth.every(1) : 6;
                xaxisLabels.transition().duration(500)
                    .call(
                        d3.axisBottom(xLine)
                        .ticks(numberOfTicks)
                        .tickFormat(d3.timeFormat("%b"))
                    )
                    .selectAll("text")
                    .style("fill", "#b2b2b2")
                    .attr("font-size", "12px");

                // update axis year labels depending on how many months there are
                let xaxisYearLabels = g.select(".x.axis-year-labels");
                xaxisYearLabels.transition().duration(500)
                    .call(
                        d3.axisBottom(xLine)
                        .ticks(numberOfTicks)
                        .tickFormat(d3.timeFormat("'%y"))
                    )
                    .selectAll("text")
                    .style("fill", "#b2b2b2")
                    .attr("font-size", "12px");

                // format x-axis lines for minor and major ticks
                //TODO: check this line to separate years starting in Jan. Maybe it is not needed
                xaxis.selectAll("g.tick line")
                    .attr("y2", d => { // d is the tick value
                        if (d3.timeFormat("%m")(d) == "01") //if it is Jan
                            return -height - 6;
                        else
                            return 6;
                    })
                    .attr("transform", d => { // d is the tick value
                        if (d3.timeFormat("%m")(d) == "01") //if it is Jan
                            return "translate(0,6)";
                    })
                    .attr("class", d => { // d is the tick value
                        if (d3.timeFormat("%m")(d) == "01") //if it is Jan
                            return "yearTick";
                    });

                let yaxis = g.select(".y.axis");
                yaxis.transition()
                    .duration(500)
                    .call(d3.axisLeft(yLine)
                        .tickFormat(yAxisFormat));

                // color axis labels
                g.selectAll(".y.axis g.tick text")
                    .style("fill", "#b2b2b2");

                // define line
                let line = d3.line()
                    .defined(d => d)
                    .curve(d3.curveMonotoneX)
                    .x(d => xLine(d.date))
                    .y(d => yLine(d.value));

                // get lines
                let lines = g.select(".lines");
                lines.selectAll("path.line")
                    .data(filteredData)
                    .join("path") // handle enter, update, and exit automagically
                    .attr("stroke", (d, i) => {
                        return i == 0 ? defaultLineColor : lineColors(i - 1);
                    })
                    .attr("class", "line")
                    .attr("fill", "none")
                    .attr("stroke-linejoin", "round")
                    .attr("stroke-linecap", "round")
                    .attr("stroke-width", 1.5)
                    .attr("d", d => line(d.values))

                // get circles
                let circles = g.select(".circles"),
                    tooltip = d3.select(".tooltip");
                //tooltipFormat = d3.timeFormat("%b "%y"),
                //tooltipFormat = d3.format(",.2f")
                //tooltipFormat = d3.format(",.3s");

                circles.selectAll("g") // using nested data, so need to make a g to contain stuff
                    .data(filteredData)
                    .join( // handle enter, update, and exit separately for overall g circle containers
                        enter => enter
                        .append("g")
                        .attr("class", d => d.name)
                        .attr("stroke", (d, i) => {
                            return i == 0 ? defaultPointColor : pointColors(i - 1);
                        })
                        .attr("fill", (d, i) => {
                            return i == 0 ? defaultPointColor : pointColors(i - 1);
                        }),
                        update => update
                        .attr("class", d => d.name)
                        .attr("stroke", (d, i) => {
                            return i == 0 ? defaultPointColor : pointColors(i - 1);
                        })
                        .attr("fill", (d, i) => {
                            return i == 0 ? defaultPointColor : pointColors(i - 1);
                        }),
                        exit => exit.remove()
                    )
                    // nested join
                    .selectAll("circle").data(d => d.values) // access internal values array for circles here
                    .join( // handle enter, update, and exit separately for circles
                        enter => enter
                        .append("circle")
                        .attr("class", "circle")
                        .attr("r", 2.5)
                        .attr("cx", d => xLine(d.date))
                        .attr("cy", d => yLine(d.value))
                        .on("mouseover", d => {
                            tooltip.html(`${tooltipFormat(d.value)} ${tooltipUnits}`);
                            let tpWidth = tooltip.node().offsetWidth; // to center tooltip
                            tooltip.style("left", `${d3.event.pageX - tpWidth / 2}px`)
                                .style("top", `${d3.event.pageY - 23}px`)
                                .style("font-family", "Consolas, courier")
                                .style("font-size", "10pt")
                                .transition()
                                .duration(200)
                                .style("opacity", .9);
                        })
                        .on("mouseout", () => {
                            tooltip.transition()
                                .duration(500)
                                .style("opacity", 0);
                        }),
                        update => update
                        .attr("cx", d => xLine(d.date))
                        .attr("cy", d => yLine(d.value)),
                        exit => exit.remove()
                    );
            }
        });
    }

    chart.width = function(value) {
        if (!arguments.length) return width;
        width = value;
        return chart;
    };

    chart.height = function(value) {
        if (!arguments.length) return height;
        height = value;
        return chart;
    };

    chart.margin = function(value) {
        if (!arguments.length) return margin;
        margin = value;
        return chart;
    };

    chart.id = function(value) {
        if (!arguments.length) return id;
        id = value;
        return chart;
    };

    chart.lineVariables = function(value) {
        if (!arguments.length) return lineVariables;
        lineVariables = value;
        return chart;
    };

    chart.displayName = function(value) {
        if (!arguments.length) return displayName;
        displayName = value;
        return chart;
    };

    chart.transitionTime = function(value) {
        if (!arguments.length) return transitionTime;
        transitionTime = value;
        return chart;
    };

    chart.legend = function(value) {
        if (!arguments.length) return legend;
        legend = value;
        return chart;
    };

    chart.legendContainer = function(value) {
        if (!arguments.length) return legendContainer;
        legendContainer = value;
        return chart;
    };

    chart.data = function(value) {
        if (!arguments.length) return data;
        data = value;
        if (typeof updateData === "function") updateData();
        return chart;
    };

    chart.lineColors = function(value) {
        if (!arguments.length) return lineColors;
        lineColors = value;
        return chart;
    };

    chart.pointColors = function(value) {
        if (!arguments.length) return pointColors;
        pointColors = value;
        return chart;
    };

    chart.xAxisFormat = function(value) {
        if (!arguments.length) return xAxisFormat;
        xAxisFormat = value;
        return chart;
    };

    chart.yAxisFormat = function(value) {
        if (!arguments.length) return yAxisFormat;
        yAxisFormat = value;
        return chart;
    };

    chart.transitionTime = function(value) {
        if (!arguments.length) return transitionTime;
        transitionTime = value;
        return chart;
    };

    chart.lineAxisLabel = function(value) {
        if (!arguments.length) return lineAxisLabel;
        lineAxisLabel = value;
        return chart;
    };

    chart.title = function(value) {
        if (!arguments.length) return title;
        title = value;
        return chart;
    };

    chart.tooltipUnits = function(value) {
        if (!arguments.length) return tooltipUnits;
        tooltipUnits = value;
        return chart;
    };

    chart.tooltipFormat = function(value) {
        if (!arguments.length) return tooltipFormat;
        tooltipFormat = value;
        return chart;
    };

    return chart;
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
function grijalva_theme(target) {
    if (target instanceof am4core.ColorSet) {
        target.list = [
            am4core.color("#00c5ff"),
            am4core.color("#ff5500"),
            am4core.color("#98e600"),
        ];
    }
}

function customizeGrip(grip) {
    // Remove default grip image
    grip.icon.disabled = true;

    // Disable background
    grip.background.disabled = true;



    // Add rotated rectangle as bi-di arrow
    var img = grip.createChild(am4core.Rectangle);
    img.width = 7;
    img.height = 7;
    img.fill = am4core.color("#999");
    img.rotation = 45;
    img.align = "center";
    img.valign = "middle";



}
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ RADAR- LINES
am4core.ready(function() {

    // Themes begin
    // am4core.useTheme(am4themes_animated);
    let mainTextColor = getComputedStyle(document.body).getPropertyValue('--main-text-color');
    // Themes end

    /* Create chart instance */
    var chart = am4core.create("radial_chart", am4charts.RadarChart);

    let title = chart.titles.create();
    title.text = "Superficie total por año";
    title.fontSize = 10;
    title.marginBottom = 10;
    title.fill = am4core.color(mainTextColor);

    var data = [];
    chart.data = data;
    //console.log(data);

    /* Create axes */
    //var categoryAxis = chart.xAxes.push(new am4charts.DateAxis());
    var categoryAxis = chart.xAxes.push(new am4charts.CategoryAxis());
    categoryAxis.dataFields.category = "month";
    categoryAxis.fontSize = 9;
    categoryAxis.renderer.labels.template.fill = am4core.color(mainTextColor);
    categoryAxis.renderer.grid.template.stroke = am4core.color(mainTextColor);


    var valueAxis = chart.yAxes.push(new am4charts.ValueAxis());
    valueAxis.renderer.grid.template.stroke = am4core.color(mainTextColor);
    valueAxis.extraMin = 0.2;
    valueAxis.extraMax = 0.2;
    valueAxis.tooltip.disabled = true;
    valueAxis.fontSize = 9;
    valueAxis.renderer.labels.template.fill = am4core.color(mainTextColor);
    valueAxis.renderer.grid.template.stroke = am4core.color(mainTextColor);
    //   valueAxis.renderer.labels.template.fontSize = 15;


    /* Create and configure series */
    var series1 = chart.series.push(new am4charts.RadarSeries());
    series1.dataFields.valueY = "value1";
    series1.dataFields.categoryX = "month" //"date";
    series1.strokeWidth = 1.5;
    series1.tooltipText = "{valueY}";
    series1.name = "2016"
    series1.stroke = am4core.color("#F98293"); // red
    series1.tooltip.getFillFromObject = false;
    series1.tooltipText = "[bold] {name}: [/]{valueY.formatNumber('#,###.0')} Ha[/]";
    series1.tooltip.background.fill = am4core.color("#F98293");

    //series1.bullets.create(am4charts.CircleBullet);
    // series1.dataItems.template.locations.dateX = 0.5;


    var series2 = chart.series.push(new am4charts.RadarSeries());
    series2.dataFields.valueY = "value2";
    series2.dataFields.categoryX = "month"; //"date";
    series2.strokeWidth = 1.5;
    series2.tooltipText = "{valueY}";
    series2.name = "2017";
    series2.stroke = am4core.color("#2AC2BB"); // red
    series2.tooltip.getFillFromObject = false;
    //series2.tooltip.background.fill = am4core.color("#");
    series2.tooltipText = "[bold] {name}: [/]{valueY.formatNumber('#,###.0')} Ha[/]";
    series2.tooltip.background.fill = am4core.color("#2AC2BB"); // red
    //series2.tooltip.background.fill = am4core.
    //series2.bullets.create(am4charts.CircleBullet);
    // series2.dataItems.template.locations.dateX = 0.5;

    var series3 = chart.series.push(new am4charts.RadarSeries());
    series3.dataFields.valueY = "value3";
    series3.dataFields.categoryX = "month"; //"date";
    series3.strokeWidth = 1.5;
    series3.tooltipText = "{valueY}";
    series3.name = "2018";
    series3.stroke = am4core.color("#FDA259"); // red
    series3.tooltipText = "[bold] {name}: [/]{valueY.formatNumber('#,###.0')} Ha[/]";
    series3.tooltip.getFillFromObject = false;
    series3.tooltip.background.fill = am4core.color("#FDA259");
    //series2.bullets.create(am4charts.CircleBullet);
    // series3.dataItems.template.locations.X = 0.5;

    chart.scrollbarX = new am4core.Scrollbar();
    chart.scrollbarX.minHeight = 1;
    chart.scrollbarX.parent = chart.bottomAxesContainer;
    chart.scrollbarY = new am4core.Scrollbar();
    chart.scrollbarY.minWidth = 1;
    customizeGrip(chart.scrollbarX.startGrip);
    customizeGrip(chart.scrollbarX.endGrip);
    customizeGrip(chart.scrollbarY.startGrip);
    customizeGrip(chart.scrollbarY.endGrip);




    chart.cursor = new am4charts.RadarCursor();

    chart.legend = new am4charts.Legend();
    // chart.legend.fontSize = 10;
    chart.legend.fontSize = 9;
    chart.legend.labels.template.fill = am4core.color(mainTextColor);


    var range_estiaje = categoryAxis.axisRanges.create();
    range_estiaje.category = "March";
    range_estiaje.endcategory = "April";
    range_estiaje.axisFill.fill = am4core.color("#595952");
    //range_estiaje.axisFill.fill = am4core.color("#DFA34D");
    range_estiaje.axisFill.fillOpacity = 0.4;
    range_estiaje.grid.strokeOpacity = 0;

    var range_estiaje_1 = categoryAxis.axisRanges.create();
    range_estiaje_1.category = "April";
    range_estiaje_1.endcategory = "May";
    range_estiaje_1.axisFill.fill = am4core.color("#595952");
    //range_estiaje_1.axisFill.fill = am4core.color("#DFA34D");
    range_estiaje_1.axisFill.fillOpacity = 0.4;
    range_estiaje_1.grid.strokeOpacity = 0;

    var range_lluvTropical = categoryAxis.axisRanges.create();
    range_lluvTropical.category = "May";
    range_lluvTropical.endcategory = "June";
    //range_lluvTropical.date = new Date(2020, 4, 1);
    //range_lluvTropical.endDate = new Date(2020, 8, 1);
    range_lluvTropical.axisFill.fill = am4core.color("#838278");
    range_lluvTropical.axisFill.fillOpacity = 0.4;
    range_lluvTropical.grid.strokeOpacity = 0;

    var range_lluvTropical_1 = categoryAxis.axisRanges.create();
    range_lluvTropical_1.category = "June";
    range_lluvTropical_1.endcategory = "July";
    range_lluvTropical_1.axisFill.fill = am4core.color("#838278");
    range_lluvTropical_1.axisFill.fillOpacity = 0.4;
    range_lluvTropical_1.grid.strokeOpacity = 0;

    var range_lluvTropical_2 = categoryAxis.axisRanges.create();
    range_lluvTropical_2.category = "July";
    range_lluvTropical_2.endcategory = "August";
    range_lluvTropical_2.axisFill.fill = am4core.color("#838278");
    range_lluvTropical_2.axisFill.fillOpacity = 0.4;
    range_lluvTropical_2.grid.strokeOpacity = 0;

    var range_lluvTropical_3 = categoryAxis.axisRanges.create();
    range_lluvTropical_3.category = "August";
    range_lluvTropical_3.endcategory = "September";
    range_lluvTropical_3.axisFill.fill = am4core.color("#838278");
    range_lluvTropical_3.axisFill.fillOpacity = 0.4;
    range_lluvTropical_3.grid.strokeOpacity = 0;

    var range_lluvTropicalInv = categoryAxis.axisRanges.create();
    range_lluvTropicalInv.category = "September";
    range_lluvTropicalInv.endcategory = "October";
    range_lluvTropicalInv.axisFill.fill = am4core.color("#B1AE9F");
    range_lluvTropicalInv.axisFill.fillOpacity = 0.4;
    range_lluvTropicalInv.grid.strokeOpacity = 0;

    var range_lluvTropicalInv_1 = categoryAxis.axisRanges.create();
    range_lluvTropicalInv_1.category = "October";
    range_lluvTropicalInv_1.endcategory = "November";
    range_lluvTropicalInv_1.axisFill.fill = am4core.color("#B1AE9F");
    range_lluvTropicalInv_1.axisFill.fillOpacity = 0.4;
    range_lluvTropicalInv_1.grid.strokeOpacity = 0;

    var range_lluvTropicalInv_2 = categoryAxis.axisRanges.create();
    range_lluvTropicalInv_2.category = "November";
    range_lluvTropicalInv_2.endcategory = "December";
    range_lluvTropicalInv_2.axisFill.fill = am4core.color("#B1AE9F");
    range_lluvTropicalInv_2.axisFill.fillOpacity = 0.4;
    range_lluvTropicalInv_2.grid.strokeOpacity = 0;

    var range_lluvInv = categoryAxis.axisRanges.create();
    range_lluvInv.category = "December";
    range_lluvInv.endcategory = "January";;
    range_lluvInv.axisFill.fill = am4core.color("#E1DBC8");
    range_lluvInv.axisFill.fillOpacity = 0.4;
    range_lluvInv.grid.strokeOpacity = 0;

    var range_lluvInv_1 = categoryAxis.axisRanges.create();
    range_lluvInv_1.category = "January";
    range_lluvInv_1.endcategory = "February";;
    range_lluvInv_1.axisFill.fill = am4core.color("#E1DBC8");
    range_lluvInv_1.axisFill.fillOpacity = 0.4;
    range_lluvInv_1.grid.strokeOpacity = 0;

    var range_lluvInv_2 = categoryAxis.axisRanges.create();
    range_lluvInv_2.category = "February";
    range_lluvInv_2.endcategory = "March";;
    range_lluvInv_2.axisFill.fill = am4core.color("#E1DBC8");
    range_lluvInv_2.axisFill.fillOpacity = 0.4;
    range_lluvInv_2.grid.strokeOpacity = 0;



    chart.legend = new am4charts.Legend();
    chart.legend.fontSize = 9;

    let legend2 = []
    var legenddata2 = [{ name: "Estiaje", fill: am4core.color("#595952") },
        { name: "Tropical", fill: am4core.color("#838278") },
        { name: "Tropical-Invernal", fill: am4core.color("#B1AE9F") },
        { name: "Invernal", fill: am4core.color("#E1DBC8") }

    ];

    //chart.legend.data = legenddata;
    chart.legend.data = legenddata2;
    chart.legend.fontSize = 10;
    chart.legend.labels.template.fill = am4core.color(mainTextColor);
    var markerTemplate = chart.legend.markers.template;
    markerTemplate.width = 20;
    markerTemplate.height = 20;

}); // end am4core.ready()

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ LINES CHARTS
am4core.ready(function() {

    // Themes begin
    am4core.useTheme(grijalva_theme);
    // Themes end

    // Create chart instance
    let chart = am4core.create("linesChart", am4charts.XYChart);

    let title = chart.titles.create();
    title.text = "Superficie por tipo de cuerpo";
    title.fontSize = 10;
    title.marginBottom = 15;
    title.fill = am4core.color(mainTextColor);

    // Increase contrast by taking evey second color
    //chart.colors.step = 2;

    // Add data
    chart.data = generateChartData();

    // Create axes
    var dateAxis = chart.xAxes.push(new am4charts.DateAxis());
    dateAxis.renderer.minGridDistance = 50;
    dateAxis.fontSize = 8;
    dateAxis.renderer.labels.template.fill = am4core.color(mainTextColor);



    // Create series
    function createAxisAndSeries(field, name, opposite, bullet) {
        var valueAxis = chart.yAxes.push(new am4charts.ValueAxis());
        valueAxis.fontSize = 8;

        if (chart.yAxes.indexOf(valueAxis) != 0) {
            valueAxis.syncWithAxis = chart.yAxes.getIndex(0);
        }

        var series = chart.series.push(new am4charts.LineSeries());
        series.dataFields.valueY = field;
        series.dataFields.dateX = "date";
        series.strokeWidth = 2;
        series.yAxis = valueAxis;
        series.name = name;
        //series.tooltipText = "{name}: [bold]{valueY.formatNumber('#,###.0')} Ha[/]";
        series.tooltipText = "[bold]{name}: [/]{valueY.formatNumber('#,###.0')} Ha[/]";
        series.tooltipText.fontSize = 8;
        series.tensionX = 0.8;
        series.showOnInit = true;

        var interfaceColors = new am4core.InterfaceColorSet();

        /*  switch (bullet) {
              case "triangle":
                  var bullet = series.bullets.push(new am4charts.Bullet());
                  bullet.width = 12;
                  bullet.height = 12;
                  bullet.horizontalCenter = "middle";
                  bullet.verticalCenter = "middle";

                  var triangle = bullet.createChild(am4core.Triangle);
                  triangle.stroke = interfaceColors.getFor("background");
                  triangle.strokeWidth = 2;
                  triangle.direction = "top";
                  triangle.width = 12;
                  triangle.height = 12;
                  break;
              case "rectangle":
                  var bullet = series.bullets.push(new am4charts.Bullet());
                  bullet.width = 10;
                  bullet.height = 10;
                  bullet.horizontalCenter = "middle";
                  bullet.verticalCenter = "middle";

                  var rectangle = bullet.createChild(am4core.Rectangle);
                  rectangle.stroke = interfaceColors.getFor("background");
                  rectangle.strokeWidth = 2;
                  rectangle.width = 10;
                  rectangle.height = 10;
                  break;
              default:
                  var bullet = series.bullets.push(new am4charts.CircleBullet());
                  bullet.circle.stroke = interfaceColors.getFor("background");
                  bullet.circle.strokeWidth = 2;
                  break;
          }*/

        valueAxis.renderer.line.strokeOpacity = 1;
        valueAxis.renderer.line.strokeWidth = 2;
        valueAxis.renderer.line.stroke = series.stroke;
        valueAxis.renderer.labels.template.fill = series.stroke;
        valueAxis.renderer.opposite = opposite;
    }

    createAxisAndSeries("permanente", "Agua permanente", false, "circle");
    createAxisAndSeries("temporal", "Áreas temporalmente inundadas", true, "triangle");
    createAxisAndSeries("vegetacion", "Suelos húmedos-vegetación acuática", true, "rectangle");

    // Add legend
    /*
    chart.legend = new am4charts.Legend();
    //chart.legend.labels.template.fill = am4core.color("#ffff");
    chart.legend.fontSize = 8;
    chart.legend.labels.template.fill = am4core.color(mainTextColor);
    chart.legend.maxHeight = 100;
*/

    // Add cursor
    chart.cursor = new am4charts.XYCursor();
    chart.scrollbarX = new am4core.Scrollbar();
    chart.scrollbarX.minHeight = 1;
    chart.scrollbarX.parent = chart.bottomAxesContainer;
    customizeGrip(chart.scrollbarX.startGrip);
    customizeGrip(chart.scrollbarX.endGrip);
    // Style scrollbar





    // generate some random data, quite different range
    function generateChartData() {
        var chartData = [];
        var firstDate = new Date();
        firstDate.setDate(firstDate.getDate() - 100);
        firstDate.setHours(0, 0, 0, 0);

        var permanente = 1600;
        var temporal = 2900;
        var vegetacion = 8700;

        /* for (var i = 0; i < 15; i++) {
             // we create date objects here. In your data, you can have date strings
             // and then set format of your dates using chart.dataDateFormat property,
             // however when possible, use date objects, as this will speed up chart rendering.
             var newDate = new Date(firstDate);
             newDate.setDate(newDate.getDate() + i);

             permanente += Math.round((Math.random() < 0.5 ? 1 : -1) * Math.random() * 10);
             temporal += Math.round((Math.random() < 0.5 ? 1 : -1) * Math.random() * 10);
             vegetacion += Math.round((Math.random() < 0.5 ? 1 : -1) * Math.random() * 10);

             chartData.push({
                 date: newDate,
                 permanente: permanente,
                 temporal: temporal,
                 vegetacion: vegetacion
             });
         }*/
        return chartData;
    }

    // axis ranges
    var range = dateAxis.axisRanges.create();
    range.date = new Date(2016, 0, 1);
    range.endDate = new Date(2016, 2, 1);
    range.axisFill.fill = am4core.color("#E1DBC8");
    range.axisFill.fillOpacity = 0.4;

    var range1 = dateAxis.axisRanges.create();
    range1.date = new Date(2016, 2, 1);
    range1.endDate = new Date(2016, 4, 1);
    range1.axisFill.fill = am4core.color("#595952");
    range1.axisFill.fillOpacity = 0.4;

    var range2 = dateAxis.axisRanges.create();
    range2.date = new Date(2016, 4, 1);
    range2.endDate = new Date(2016, 8, 1);
    range2.axisFill.fill = am4core.color("#838278");
    range2.axisFill.fillOpacity = 0.4;

    var range2 = dateAxis.axisRanges.create();
    range2.date = new Date(2016, 8, 1);
    range2.endDate = new Date(2016, 11, 1);
    range2.axisFill.fill = am4core.color("#B1AE9F");
    range2.axisFill.fillOpacity = 0.4;

    var range3 = dateAxis.axisRanges.create();
    range3.date = new Date(2016, 11, 1);
    range3.endDate = new Date(2017, 2, 1);
    range3.axisFill.fill = am4core.color("#E1DBC8");
    range3.axisFill.fillOpacity = 0.4;

    var range4 = dateAxis.axisRanges.create();
    range4.date = new Date(2017, 2, 1);
    range4.endDate = new Date(2017, 4, 1);
    range4.axisFill.fill = am4core.color("#595952");
    range4.axisFill.fillOpacity = 0.4;

    var range5 = dateAxis.axisRanges.create();
    range5.date = new Date(2017, 4, 1);
    range5.endDate = new Date(2017, 8, 1);
    range5.axisFill.fill = am4core.color("#838278");
    range5.axisFill.fillOpacity = 0.4;

    var range6 = dateAxis.axisRanges.create();
    range6.date = new Date(2017, 8, 1);
    range6.endDate = new Date(2017, 11, 1);
    range6.axisFill.fill = am4core.color("#B1AE9F");
    range6.axisFill.fillOpacity = 0.4;

    var range7 = dateAxis.axisRanges.create();
    range7.date = new Date(2017, 11, 1);
    range7.endDate = new Date(2018, 2, 1);
    range7.axisFill.fill = am4core.color("#E1DBC8");
    range7.axisFill.fillOpacity = 0.4;

    var range8 = dateAxis.axisRanges.create();
    range8.date = new Date(2018, 2, 1);
    range8.endDate = new Date(2018, 4, 1);
    range8.axisFill.fill = am4core.color("#595952");
    range8.axisFill.fillOpacity = 0.4;

    var range9 = dateAxis.axisRanges.create();
    range9.date = new Date(2018, 4, 1);
    range9.endDate = new Date(2018, 8, 1);
    range9.axisFill.fill = am4core.color("#838278");
    range9.axisFill.fillOpacity = 0.4;

    var range10 = dateAxis.axisRanges.create();
    range10.date = new Date(2018, 8, 1);
    range10.endDate = new Date(2018, 11, 1);
    range10.axisFill.fill = am4core.color("#B1AE9F");
    range10.axisFill.fillOpacity = 0.4;

    var range11 = dateAxis.axisRanges.create();
    range11.date = new Date(2018, 11, 1);
    range11.endDate = new Date(2019, 0, 1);
    range11.axisFill.fill = am4core.color("#E1DBC8");
    range11.axisFill.fillOpacity = 0.4;

}); // end am4core.ready()

//------------------------------------------------------------------------------------------------------------------------------------ STACKED AREAS
am4core.ready(function() {

    // Themes begin
    am4core.useTheme(am4themes_animated);
    // Themes end

    let chart = am4core.create("stackedAreaChart", am4charts.XYChart);

    let title = chart.titles.create();
    title.text = "Superficie acumulada";
    title.fontSize = 10;
    title.marginBottom = 15;
    title.fill = am4core.color(mainTextColor);

    // chart.dateFormatter.inputDateFormat = "dd-mm-yyyy";
    var dateAxis = chart.xAxes.push(new am4charts.DateAxis());
    dateAxis.renderer.minGridDistance = 60;
    dateAxis.fontSize = 8;
    dateAxis.renderer.labels.template.fill = am4core.color(mainTextColor);
    dateAxis.startLocation = 0.5;
    dateAxis.endLocation = 0.5;
    dateAxis.baseInterval = {
        timeUnit: "month",
        count: 1
    }

    var valueAxis = chart.yAxes.push(new am4charts.ValueAxis());
    valueAxis.tooltip.disabled = true;
    valueAxis.fontSize = 8;
    valueAxis.renderer.labels.template.fill = am4core.color(mainTextColor);

    var series = chart.series.push(new am4charts.LineSeries());
    series.dataFields.dateX = "date";
    series.name = "Agua permanente";
    series.dataFields.valueY = "permanente";
    //series.tooltipHTML = "<img src='https://www.amcharts.com/lib/3/images/car.png' style='vertical-align:bottom; margin-right: 10px; width:28px; height:21px;'><span style='font-size:14px; color:#000000;'><b>{valueY.value}</b></span>";
    //series.tooltipText = "[#000]{valueY.value}[/]";
    series.tooltipText = "[bold]{name}: [/]{valueY.formatNumber('#,###.#')} Ha";
    //series.tooltip.background.fill = am4core.color("#FFF");
    series.tooltip.getStrokeFromObject = true;
    series.tooltip.background.strokeWidth = 3;
    //series.tooltip.getFillFromObject = false;
    series.fillOpacity = 0.6;
    series.strokeWidth = 2;
    series.stacked = true;

    var series2 = chart.series.push(new am4charts.LineSeries());
    series2.name = "Áreas temporalmente inundadas";
    series2.dataFields.dateX = "date";
    series2.dataFields.valueY = "temporal";
    //series2.tooltipHTML = "<img src='https://www.amcharts.com/lib/3/images/motorcycle.png' style='vertical-align:bottom; margin-right: 10px; width:28px; height:21px;'><span style='font-size:14px; color:#000000;'><b>{valueY.value}</b></span>";
    //series2.tooltipText = "[#000]{valueY.value}[/]";
    series2.tooltipText = "[bold]{name}: [/]{valueY.formatNumber('#,###.#')} Ha";
    //series2.tooltip.background.fill = am4core.color("#FFF");
    //series2.tooltip.getFillFromObject = false;
    series2.tooltip.getStrokeFromObject = true;
    series2.tooltip.background.strokeWidth = 3;
    series2.sequencedInterpolation = true;
    series2.fillOpacity = 0.6;
    series2.stacked = true;
    series2.strokeWidth = 2;

    var series3 = chart.series.push(new am4charts.LineSeries());
    series3.name = "Suelos húmedos-vegetación acuática";
    series3.dataFields.dateX = "date";
    series3.dataFields.valueY = "vegetacion";
    //series3.tooltipHTML = "<img src='https://www.amcharts.com/lib/3/images/bicycle.png' style='vertical-align:bottom; margin-right: 10px; width:28px; height:21px;'><span style='font-size:14px; color:#000000;'><b>{valueY.value}</b></span>";
    // series3.tooltipText = "[#000]{valueY.value}[/]";
    series3.tooltipText = "[bold]{name}: [/]{valueY.formatNumber('#,###.#')} Ha";
    //series3.tooltip.background.fill = am4core.color("#FFF");
    //series3.tooltip.getFillFromObject = false;
    series3.tooltip.getStrokeFromObject = true;
    series3.tooltip.background.strokeWidth = 3;
    series3.sequencedInterpolation = true;
    series3.fillOpacity = 0.6;
    series3.defaultState.transitionDuration = 1000;
    series3.stacked = true;
    series3.strokeWidth = 2;

    chart.cursor = new am4charts.XYCursor();
    chart.cursor.xAxis = dateAxis;
    chart.scrollbarX = new am4core.Scrollbar();
    chart.scrollbarX.minHeight = 1;
    chart.scrollbarX.parent = chart.bottomAxesContainer;
    customizeGrip(chart.scrollbarX.startGrip);
    customizeGrip(chart.scrollbarX.endGrip);
    //chart.scrollbarX.position = "bottom";

    // Add a legend 
    // axis ranges
    var range = dateAxis.axisRanges.create();
    range.date = new Date(2016, 0, 1);
    range.endDate = new Date(2016, 2, 1);
    range.axisFill.fill = am4core.color("#E1DBC8");
    range.axisFill.fillOpacity = 0.4;

    var range1 = dateAxis.axisRanges.create();
    range1.date = new Date(2016, 2, 1);
    range1.endDate = new Date(2016, 4, 1);
    range1.axisFill.fill = am4core.color("#595952");
    range1.axisFill.fillOpacity = 0.4;

    var range2 = dateAxis.axisRanges.create();
    range2.date = new Date(2016, 4, 1);
    range2.endDate = new Date(2016, 8, 1);
    range2.axisFill.fill = am4core.color("#838278");
    range2.axisFill.fillOpacity = 0.4;

    var range2 = dateAxis.axisRanges.create();
    range2.date = new Date(2016, 8, 1);
    range2.endDate = new Date(2016, 11, 1);
    range2.axisFill.fill = am4core.color("#B1AE9F");
    range2.axisFill.fillOpacity = 0.4;

    var range3 = dateAxis.axisRanges.create();
    range3.date = new Date(2016, 11, 1);
    range3.endDate = new Date(2017, 2, 1);
    range3.axisFill.fill = am4core.color("#E1DBC8");
    range3.axisFill.fillOpacity = 0.4;

    var range4 = dateAxis.axisRanges.create();
    range4.date = new Date(2017, 2, 1);
    range4.endDate = new Date(2017, 4, 1);
    range4.axisFill.fill = am4core.color("#595952");
    range4.axisFill.fillOpacity = 0.4;

    var range5 = dateAxis.axisRanges.create();
    range5.date = new Date(2017, 4, 1);
    range5.endDate = new Date(2017, 8, 1);
    range5.axisFill.fill = am4core.color("#838278");
    range5.axisFill.fillOpacity = 0.4;

    var range6 = dateAxis.axisRanges.create();
    range6.date = new Date(2017, 8, 1);
    range6.endDate = new Date(2017, 11, 1);
    range6.axisFill.fill = am4core.color("#B1AE9F");
    range6.axisFill.fillOpacity = 0.4;

    var range7 = dateAxis.axisRanges.create();
    range7.date = new Date(2017, 11, 1);
    range7.endDate = new Date(2018, 2, 1);
    range7.axisFill.fill = am4core.color("#E1DBC8");
    range7.axisFill.fillOpacity = 0.4;

    var range8 = dateAxis.axisRanges.create();
    range8.date = new Date(2018, 2, 1);
    range8.endDate = new Date(2018, 4, 1);
    range8.axisFill.fill = am4core.color("#595952");
    range8.axisFill.fillOpacity = 0.4;

    var range9 = dateAxis.axisRanges.create();
    range9.date = new Date(2018, 4, 1);
    range9.endDate = new Date(2018, 8, 1);
    range9.axisFill.fill = am4core.color("#838278");
    range9.axisFill.fillOpacity = 0.4;

    var range10 = dateAxis.axisRanges.create();
    range10.date = new Date(2018, 8, 1);
    range10.endDate = new Date(2018, 11, 1);
    range10.axisFill.fill = am4core.color("#B1AE9F");
    range10.axisFill.fillOpacity = 0.4;

    var range11 = dateAxis.axisRanges.create();
    range11.date = new Date(2018, 11, 1);
    range11.endDate = new Date(2019, 0, 1);
    range11.axisFill.fill = am4core.color("#E1DBC8");
    range11.axisFill.fillOpacity = 0.4;


    /* Set up cursor behavior */
    chart.cursor.events.on("cursorpositionchanged", function(ev) {
        let xAxis = ev.target.chart.xAxes.getIndex(0);
        let yy = xAxis.positionToDate(xAxis.toAxisPosition(ev.target.xPosition)).getFullYear().toString();
        let mm = xAxis.positionToDate(xAxis.toAxisPosition(ev.target.xPosition)).getMonth().toString();
        let month = 0,
            startDate = 0,
            endDate = 0;
        if (mm < 9) { month = "0" + (parseInt(mm) + 1).toString(); } else {
            month = parseInt(mm) + 1;
            month.toString();
        }
        filterDate = new Date(`${yy}-${month}-01T00:00:00`);
        updateBarChart(filterDate, barChartData);

    })

    /* popChart.cursor = new am4charts.XYCursor();
popChart.snapToSeries = popSeriesFemale;
popChart.cursor.events.on("cursorpositionchanged", function(ev) {
  currentYear = popXAxis.positionToDate(popXAxis.toAxisPosition(ev.target.xPosition)).getFullYear().toString();
  updateData();
});*/

    /* range.label.text = "Fines for speeding increased";
     range.label.inside = true;
     range.label.rotation = 90;
     range.label.horizontalCenter = "right";
     range.label.verticalCenter = "bottom";*/




    /*  range2.label.text = "Motorcycle fee introduced";
      range2.label.inside = true;
      range2.label.rotation = 90;
      range2.label.horizontalCenter = "right";
      range2.label.verticalCenter = "bottom";*/

}); // end am4core.ready()

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ POPULATION BARS
am4core.ready(function() {

    // Themes begin
    am4core.useTheme(am4themes_animated);
    // Themes end

    // Create chart instance
    var chart = am4core.create("dimfrcpo-graph", am4charts.XYChart);

    let title = chart.titles.create();
    title.text = "Conteo por tipo de cuerpo";
    title.fontSize = 10;
    title.marginBottom = 5;
    title.fill = am4core.color(mainTextColor);


    // Create axes
    //var categoryAxis = chart.yAxes.push(new am4charts.CategoryAxis());
    var categoryAxis = chart.xAxes.push(new am4charts.CategoryAxis());
    categoryAxis.dataFields.category = "grupo";
    categoryAxis.numberFormatter.numberFormat = "#,###.#";
    categoryAxis.renderer.inversed = true;
    categoryAxis.renderer.grid.template.location = 0;
    categoryAxis.renderer.cellStartLocation = 0.1;
    categoryAxis.renderer.cellEndLocation = 0.9;
    categoryAxis.fontSize = 10;
    categoryAxis.renderer.labels.template.fill = am4core.color(mainTextColor);
    categoryAxis.title.text = "Superficie (Ha)";
    categoryAxis.title.fill = am4core.color(mainTextColor);

    /*var dateAxis = chart.yAxes.push(new am4charts.DateAxis());
    dateAxis.dataFields.date = "date"; //"year";
    //dateAxis.numberFormatter.numberFormat = "#";
    dateAxis.renderer.inversed = true;
    dateAxis.renderer.grid.template.location = 0;
    dateAxis.renderer.cellStartLocation = 0.1;
    dateAxis.renderer.cellEndLocation = 0.9;
    dateAxis.fontSize = 10;
    dateAxis.renderer.labels.template.fill = am4core.color(mainTextColor);*/



    //var valueAxis = chart.xAxes.push(new am4charts.ValueAxis());
    var valueAxis = chart.yAxes.push(new am4charts.ValueAxis());
    //valueAxis.renderer.opposite = true;
    //valueAxis.calculateTotals = true
    valueAxis.fontSize = 10;
    valueAxis.extraMax = 0.05;
    valueAxis.renderer.labels.template.fill = am4core.color(mainTextColor);



    // Create series
    function createSeries(field, name) {
        var series = chart.series.push(new am4charts.ColumnSeries());
        // series.dataFields.valueX = field;
        //series.dataFields.categoryY = "grupo";
        series.dataFields.valueY = field;
        series.dataFields.categoryX = "grupo";
        // series.dataFields.valueYShow = "count";

        // series.dataFields.categoryY = "grupo"; //"year";
        series.dataFields.categoryX = "grupo"; //"year";
        series.name = name;
        series.columns.template.tooltipText = "[underline][bold]Menor a [bold]{categoryX.formatNumber('#,###.#')} Ha[/]: {valueY.formatNumber('#,###.#')} cuerpos[/]";
        series.columns.template.height = am4core.percent(100);
        series.sequencedInterpolation = true;


        var valueLabel = series.bullets.push(new am4charts.LabelBullet());
        //valueLabel.label.text = "{valueX}";
        valueLabel.label.text = "{valueY}";
        valueLabel.label.horizontalCenter = "middle";
        //valueLabel.label.verticalCenter = "top";
        //valueLabel.label.align = "center";
        valueLabel.label.dx = 3;
        valueLabel.label.dy = -5;
        valueLabel.label.hideOversized = false;
        valueLabel.label.truncate = false;
        valueLabel.fontSize = 10;
        //valueLabel.label.fill = am4core.color(mainTextColor);
        valueLabel.label.fill = am4core.color("#fff");

        /* var categoryLabel = series.bullets.push(new am4charts.LabelBullet());
         categoryLabel.label.text = "{name}";
         categoryLabel.label.horizontalCenter = "right";
         categoryLabel.label.dx = -10;
         //categoryLabel.label.fill = am4core.color("#fff");
         categoryLabel.label.hideOversized = false;
         categoryLabel.label.truncate = false;
         categoryLabel.fontSize = 12;*/
    }

    createSeries("ap", "Agua permanente");
    createSeries("at", "Áreas temporalmente inundadas");
    createSeries("av", "Suelos húmedos-vegetación acuática");

    // Add a legend
    /*
    chart.legend = new am4charts.Legend();
    // chart.legend.position = "top";
    chart.legend.fontSize = 10;
    chart.legend.labels.template.fill = am4core.color(mainTextColor);*/

}); // end am4core.ready()

//--------------------------------------------------------------------------------------------------------------------